package org.greenstone.gatherer.metadata;


import java.io.*;
import java.util.*;


/** This class is a static class that manages the metadata sets */
public class MetadataSetManager
{
    static public final String EXTRACTED_METADATA_NAMESPACE = "ex";

    static private ArrayList metadata_sets = new ArrayList();


    static public void clearMetadataSets()
    {
	metadata_sets.clear();
    }


    static public int compareMetadataElements(MetadataElement metadata_element_a, MetadataElement metadata_element_b)
    {
	// First compare the namespaces of the two metadata elements
	if (!metadata_element_a.getNamespace().equals(metadata_element_b.getNamespace())) {
	    return metadata_element_a.getNamespace().compareTo(metadata_element_b.getNamespace());
	}

	// Otherwise compare the two elements within the one set
	MetadataSet metadata_set = getMetadataSet(metadata_element_a.getNamespace());
	return metadata_set.compareMetadataElements(metadata_element_a, metadata_element_b);
    }


    static public ArrayList getEveryMetadataSetElement()
    {
	ArrayList every_metadata_set_element = new ArrayList();

	for (int i = 0; i < metadata_sets.size(); i++) {
	    MetadataSet metadata_set = (MetadataSet) metadata_sets.get(i);
	    every_metadata_set_element.addAll(metadata_set.getMetadataSetElements());
	}

	return every_metadata_set_element;
    }


    static public MetadataSet getMetadataSet(String metadata_set_namespace)
    {
	// Find the desired metadata set in the list
	for (int i = 0; i < metadata_sets.size(); i++) {
	    MetadataSet metadata_set = (MetadataSet) metadata_sets.get(i);
	    if (metadata_set.getNamespace().equals(metadata_set_namespace)) {
		return metadata_set;
	    }
	}

	// Not found
	System.err.println("No metadata set with namespace " + metadata_set_namespace + " found.");
	return null;
    }


    static public ArrayList listMetadataSets(File directory)
    {
	// Make sure the directory (metadata) exists
	if (directory.exists() == false) {
	    return null;
	}

	// Load just those .mds files in this directory, and return them
	ArrayList directory_metadata_sets = new ArrayList();
	File[] directory_files = directory.listFiles();
	for (int i = 0; i < directory_files.length; i++) {
	    File child_file = directory_files[i];
	    if (!child_file.isDirectory() && child_file.getName().endsWith(".mds")) {
		MetadataSet metadata_set = new MetadataSet(child_file);
		directory_metadata_sets.add(metadata_set);
	    }
	}

	return directory_metadata_sets;
    }


    static public void loadMetadataSets(File directory)
    {
	// Make sure the directory (metadata) exists
	if (directory.exists() == false) {
	    return;
	}

	// Look recursively at each subfile of the directory for .mds files
	File[] directory_files = directory.listFiles();
	for (int i = 0; i < directory_files.length; i++) {
	    File child_file = directory_files[i];
	    if (child_file.isDirectory()) {
		loadMetadataSets(child_file);
	    }
	    else if (child_file.getName().endsWith(".mds")) {
		loadMetadataSet(child_file);
	    }
	}
    }


    static private void loadMetadataSet(File metadata_set_file)
    {
	MetadataSet metadata_set = new MetadataSet(metadata_set_file);
	metadata_sets.add(metadata_set);
    }
}
